import { Survey, SurveyChoice } from "../entities/Survey";
import { RequestHandler } from "../entities/RequestHandler";
import { SurveyHelper } from "../helpers/SurveyHelper";

/**
 * Survey controller
 * 
 * @author Pierre HUBERT
 */

export class SurveyController {


	/**
	 * Turn a survey into an API entry
	 * 
	 * @param h Request handler
	 * @param survey The survey
	 */
	public static async SurveyToAPI(h: RequestHandler, survey: Survey) : Promise<any> {
		let data  = {
			ID: survey.id,
			userID: survey.userID,
			postID: survey.postID,
			creation_time: survey.timeCreate,
			question: survey.question,
			user_choice: -1,
			choices: {},
		}

		survey.choices.forEach((c) => data.choices[c.id.toString()] = this.SurveyChoiceToAPI(c))

		if(h.signedIn)
			data.user_choice = await SurveyHelper.GetUserChoice(survey.id, h.getUserId());

		return data;
	}

	/**
	 * Turn a survey choice into an API entry
	 * 
	 * @param c The choice
	 */
	private static SurveyChoiceToAPI(c: SurveyChoice) {
		return {
			choiceID: c.id,
			name: c.name,
			responses: c.count
		}
	}
}